@@ -13,7 +13,7 @@ ChaptersDialog::ChaptersDialog(Book *b, QWidget *parent):
 
     QFrame *frame = new QFrame(this);
     setCentralWidget(frame);
-    QHBoxLayout *horizontalLayout = new QHBoxLayout(this);
+    QHBoxLayout *horizontalLayout = new QHBoxLayout(frame);
     frame->setLayout(horizontalLayout);
 
     list = new QListWidget(this);
