@@ -9,14 +9,14 @@ class FullScreenWindow: public QMainWindow
 {
     Q_OBJECT
 public:
-    explicit FullScreenWindow(QWidget *child, QWidget *parent);
+    explicit FullScreenWindow(QWidget *parent);
     void showFullScreen();
+    void takeChild(QWidget *child);
+    void leaveChild();
 
 signals:
     void restore();
 
-public slots:
-
 protected:
 #ifdef Q_WS_MAEMO_5
 #   define MOUSE_ACTIVATE_EVENT mouseReleaseEvent
@@ -27,6 +27,7 @@ protected:
     virtual void resizeEvent(QResizeEvent *event);
     QRect fullScreenZone() const;
     TranslucentButton *restoreButton;
+    QWidget *child;
 };
 
 #endif // FULLSCREENWINDOW_H
